@@ -3,7 +3,7 @@ import cv2,os,sys
 from PIL import Image
 import numpy as np
 
-currentDir = os.path.dirname(os.path.realpath(__file__))
+currentDir = os.getcwd()
 sys.path.append(os.path.join(currentDir,"function"))
 from .function import number,heart,thumb,power,peace,ok,loveu
 
